#!/usr/bin/env pybricks-micropython
from pybricks.hubs import EV3Brick
from pybricks.ev3devices import (Motor, TouchSensor, ColorSensor,
                                 InfraredSensor, UltrasonicSensor, GyroSensor)
from pybricks.parameters import Port, Stop, Direction, Button, Color
from pybricks.tools import wait, StopWatch, DataLog
from pybricks.robotics import DriveBase
from pybricks.media.ev3dev import SoundFile, ImageFile
import time


# Controller (EV3 Mindstorms Home Edition).
ev3 = EV3Brick()

# Motors - B(Left), C(Right).
mC = Motor(Port.C)
mB = Motor(Port.B)
mt = DriveBase(mC, mB, 6.5, 15)

# Colorsensors - S2(Left), S3(Right).
c1 = ColorSensor(Port.S3)
c2 = ColorSensor(Port.S2)

# IR sensors - 1(Right), 4(Front).
ir1 = InfraredSensor(Port.S1)
ir4 = InfraredSensor(Port.S4)

# Regulator Options.
KP = int(0.8)
steering_limit = int(800)
speed = int(-180) # Max 250.
steering = int(0)

# Test.
ev3.speaker.beep()
ev3.speaker.beep()
print('Hello)')


# Helper functions.
def TurnMotor(mB, mC, steering, speed):
    steering *= abs(speed)/steering_limit
    L = speed - steering
    R = speed + steering

    mB.run(L)
    mC.run(R)
    
    steering *= KP
    
def trg():
    ev3.speaker.beep()
    ev3.speaker.beep()
    mt.drive_time(0, 100, 800)
    mt.drive_time(-100, 0, 650)
    mt.drive_time(0, -100, 900) #820 old
    mt.drive_time(-100, -10, 900)
    mt.drive_time(-90, -100, 1100)
    mt.drive_time(-90, 0, 200)
    mt.drive_time(0, 100, 1060)
    ev3.speaker.beep()

def stop():
    mB.run(0)
    mC.run(0)
    

# Parts.
def FirstPart():
    global steering

    # Alert of starting.
    ev3.speaker.beep()

    while not ir4.distance() <= 12:
        steering = c2.reflection() - c1.reflection()
        steering *= 10
        TurnMotor(mB, mC, steering, speed)
    
    trg()
    time1 = time.time()
    # In while - Msec.
    while True:
        if time.time() - time1 >= 20:
            break
        steering = c2.reflection() - c1.reflection()
        steering *= 10
        TurnMotor(mB, mC, steering, speed)
    
    # Alert of finishing.
    ev3.speaker.beep()